
import { csv, select,legendColor } from 'd3';
import { scatterPlot } from './scatterPlot';


const csvUrl ='https://gist.githubusercontent.com/suchitra2602/3348f89f5afc867a4e01f7d49f18c49b/raw/a7d9ee929c838b2fcd57a66da32a2701200ec43b/wheat.csv';

// Data gets splits, using parsing
const parseRow = (d) => {
  d.Area = +d.Area;
  d.Perimeter = +d.Perimeter;
  d.Kernel_Length = +d.Kernel_Length;
  d.Kernal_Width = +d.Kernel_Width;
  return d;
};

const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

// values to be viewed on X-labels
const xValue = (d) => d.Kernel_Length;
const yValue = (d) => d.Kernel_Width;
const rxValue = (d) => d.Area;
const ryValue = (d) => d.Perimeter;
const TypeValue = (d) => d.Type;
const colorValue = d => d.Type;
const colorLabel = 'Types of wheat';

//Adding the legends
const main = async () => {
  const data = await csv(csvUrl, parseRow);
  const x = xValue((d) => d.Kernel_width);
  const y = yValue((d) => d.Area);
  const marker = (d) => {
        	switch(d){
            case 'Kama':
              return 'blue';
            case 'Rosa':
              return 'yellow';
            default:
              return 'red';
          }
        }
  
  const marks = data.map((d) => ({
          x: xValue((d) => d.Kernel_Width),
          y: yValue((d) => d.Area),
          Type: TypeValue(d),
          color: marker(TypeValue(d)),
        	rx: rxValue(d),
          ry: ryValue(d),
                      
        }));
  
  
//Defining scatterplot structure
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.Kernel_Width)
    .yValue((d) => d.Area)
    .margin({
      top: 35,
      right: 50,
      bottom: 80,
      left: 95,

    })
    .radius(5);
  
  
 const g = svg.append('g')
          .attr('transform', `translate(${100},${100})`);

      const colorLegendG = g.append('g')
          .attr('transform', `translate(${100}, 150)`);


//Declaring the shape and structure of data points  
svg
          .selectAll('circle')
          .data(marks)
          .join('circle')
          .attr('cx', (d) => d.x)
          .attr('cy', (d) => d.y)
        	.attr('fill', (d) => d.color)
        	.attr('rx', (d) => (d.rx))
        	.attr('ry', (d) => (d.ry));
  
  const columns = [
    'Area',
    'Perimeter',
    'Kernel_Length',
    'Kernel_Width',
  ];
  
  let i = 0;
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]);  /* Generates  'Area',
    'Perimeter',
    'Kernel_Length',
    'Kernel_Width,*/
		svg.selectAll('text').remove();
    svg.call(plot);
    
      colorLegendG.append('text')
          .attr('class', 'legend-label')
          .attr('x', -70)
          .attr('y', -210)
          .style("font-style","italic")
          .style("stroke","black")
          .text(colorLabel);

   
// Title
svg.append("text").attr("x", 450).attr("y", 20).text("ICE-7 Reusable Scatterplot").style("font-size", "35px").attr("alignment-baseline","middle")

// Add labels in the legend
svg.append("text").attr("x", 150).attr("y", 70).text("Kama").style("font-size", "20px").attr("alignment-baseline","middle")
svg.append("text").attr("x", 150).attr("y", 100).text("Rosa").style("font-size", "20px").attr("alignment-baseline","middle")
svg.append("text").attr("x", 150).attr("y", 130).text("Canadian").style("font-size", "20px").attr("alignment-baseline","middle")
    svg
        	.append("text")
        	.attr('transform', 'rotate(-90)')
        	.attr('x',0 - (height /2))
        	.attr("y",  height/12)
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
        	.text("Area"); 
    // Add points for legend
    svg.append("circle").attr("cx",130).attr("cy",70).attr("r", 6).style("fill", "green")
		svg.append("circle").attr("cx",130).attr("cy",100).attr("r", 6).style("fill", "yellow")
		svg.append("circle").attr("cx",130).attr("cy",130).attr("r", 6).style("fill", "red")
   // plot Kernel_width on x-axis
    if(i % columns.length==0) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","Ariel")
        	.style("font-weight","bold")
      		.text("Kernel Width");
     // plot Perimeter on x-axis
    else if(i % columns.length==1) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","Ariel")
        	.style("font-weight","bold")
      		.text("Perimeter");
     // plot Kernel_length on x-axis
    else if(i % columns.length==2) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","Ariel")
        	.style("font-weight","bold")
      		.text("Kernel Length");
     // plot Area on x-axis
       else 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","Ariel")
        	.style("font-weight","bold")
      		.text("Area");
    i++;
  }, 2000);// every 2 seconds change the visualization
};
main();



